==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Posao</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Život</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostalo</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Jedan dan prije početka</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Podsjeti me sutra</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Podsjeti me kasnije</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minuta kasnije</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 sat kasnije</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 sata kasnije</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Sutra</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Podsjetnik rasporeda</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 do %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Danas</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Dan prije početka</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Zatvori</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Podsjeti me sutra</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Podsjeti me kasnije</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Podsjetnik rasporeda</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 do %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Danas</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Sutra</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Posao</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Život</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostalo</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Jedan dan prije početka</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Podsjeti me sutra</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Podsjeti me kasnije</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minuta kasnije</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 sat kasnije</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 sata kasnije</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Sutra</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Podsjetnik rasporeda</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 do %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Danas</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
